/**
 * Adds a transformation step to a schema, which is executed at the end of
 * parsing and can change the output type.
 *
 * @param schema The scheme to be used.
 * @param action The transformation action.
 *
 * @returns A transformed schema.
 */
export function transform(schema, action) {
    return {
        ...schema,
        /**
         * Parses unknown input based on its schema.
         *
         * @param input The input to be parsed.
         * @param info The parse info.
         *
         * @returns The parsed output.
         */
        parse(input, info) {
            return action(schema.parse(input, info));
        },
    };
}
