/**
 * Adds an async transformation step to a schema, which is executed at the end
 * of parsing and can change the output type.
 *
 * @param schema The scheme to be used.
 * @param action The transformation action.
 *
 * @returns A transformed schema.
 */
export function transformAsync(schema, action) {
    return {
        ...schema,
        /**
         * Whether it's async.
         */
        async: true,
        /**
         * Parses unknown input based on its schema.
         *
         * @param input The input to be parsed.
         * @param info The parse info.
         *
         * @returns The parsed output.
         */
        async parse(input, info) {
            return action(await schema.parse(input, info));
        },
    };
}
