import { ValiError } from '../../error';
import { executePipe, getCurrentPath, getErrorAndPipe } from '../../utils';
export function array(item, arg2, arg3) {
    // Get error and pipe argument
    const { error, pipe } = getErrorAndPipe(arg2, arg3);
    // Create and return array schema
    return {
        /**
         * The schema type.
         */
        schema: 'array',
        /**
         * The array item schema.
         */
        array: { item },
        /**
         * Whether it's async.
         */
        async: false,
        /**
         * Parses unknown input based on its schema.
         *
         * @param input The input to be parsed.
         * @param info The parse info.
         *
         * @returns The parsed output.
         */
        parse(input, info) {
            // Check type of input
            if (!Array.isArray(input)) {
                throw new ValiError([
                    {
                        reason: 'type',
                        validation: 'array',
                        origin: 'value',
                        message: error || 'Invalid type',
                        input,
                        ...info,
                    },
                ]);
            }
            // Create output and issues
            const output = [];
            const issues = [];
            // Parse schema of each array item
            input.forEach((value, index) => {
                try {
                    output.push(item.parse(value, {
                        ...info,
                        path: getCurrentPath(info, {
                            schema: 'array',
                            input: input,
                            key: index,
                            value,
                        }),
                    }));
                    // Fill issues in case of an error
                }
                catch (error) {
                    issues.push(...error.issues);
                }
            });
            // Throw error if there are issues
            if (issues.length) {
                throw new ValiError(issues);
            }
            // Execute pipe and return output
            return executePipe(output, pipe, {
                ...info,
                reason: 'array',
            });
        },
    };
}
