import { ValiError } from '../../error';
import { executePipe, getErrorAndPipe } from '../../utils';
export function bigint(arg1, arg2) {
    // Get error and pipe argument
    const { error, pipe } = getErrorAndPipe(arg1, arg2);
    // Create and return bigint schema
    return {
        /**
         * The schema type.
         */
        schema: 'bigint',
        /**
         * Whether it's async.
         */
        async: false,
        /**
         * Parses unknown input based on its schema.
         *
         * @param input The input to be parsed.
         * @param info The parse info.
         *
         * @returns The parsed output.
         */
        parse(input, info) {
            // Check type of input
            if (typeof input !== 'bigint') {
                throw new ValiError([
                    {
                        reason: 'type',
                        validation: 'bigint',
                        origin: 'value',
                        message: error || 'Invalid type',
                        input,
                        ...info,
                    },
                ]);
            }
            // Execute pipe and return output
            return executePipe(input, pipe, { ...info, reason: 'bigint' });
        },
    };
}
