import { ValiError } from '../../error';
/**
 * Creates a enum schema.
 *
 * @param enum The enum value.
 * @param error The error message.
 *
 * @returns A enum schema.
 */
export function enumType(enumValue, error) {
    return {
        /**
         * The schema type.
         */
        schema: 'enum',
        /**
         * The enum value.
         */
        enum: enumValue,
        /**
         * Whether it's async.
         */
        async: false,
        /**
         * Parses unknown input based on its schema.
         *
         * @param input The input to be parsed.
         * @param info The parse info.
         *
         * @returns The parsed output.
         */
        parse(input, info) {
            // Check type of input
            if (!enumValue.includes(input)) {
                throw new ValiError([
                    {
                        reason: 'type',
                        validation: 'enum',
                        origin: 'value',
                        message: error || 'Invalid type',
                        input,
                        ...info,
                    },
                ]);
            }
            // Return output
            return input;
        },
    };
}
