import { ValiError } from '../../error';
/**
 * Creates a literal schema.
 *
 * @param literal The literal value.
 * @param error The error message.
 *
 * @returns A literal schema.
 */
export function literal(literal, error) {
    return {
        /**
         * The schema type.
         */
        schema: 'literal',
        /**
         * The literal value.
         */
        literal,
        /**
         * Whether it's async.
         */
        async: false,
        /**
         * Parses unknown input based on its schema.
         *
         * @param input The input to be parsed.
         * @param info The parse info.
         *
         * @returns The parsed output.
         */
        parse(input, info) {
            // Check type of input
            if (input !== literal) {
                throw new ValiError([
                    {
                        reason: 'type',
                        validation: 'literal',
                        origin: 'value',
                        message: error || 'Invalid type',
                        input,
                        ...info,
                    },
                ]);
            }
            // Return output
            return input;
        },
    };
}
