/**
 * Creates a optional schema.
 *
 * @param wrapped The wrapped schema.
 *
 * @returns A optional schema.
 */
export function optional(wrapped) {
    return {
        /**
         * The schema type.
         */
        schema: 'optional',
        /**
         * The wrapped schema.
         */
        wrapped,
        /**
         * Whether it's async.
         */
        async: false,
        /**
         * Parses unknown input based on its schema.
         *
         * @param input The input to be parsed.
         * @param info The parse info.
         *
         * @returns The parsed output.
         */
        parse(input, info) {
            // Allow `undefined` values to pass
            if (input === undefined) {
                return input;
            }
            // Parse wrapped schema and return output
            return wrapped.parse(input, info);
        },
    };
}
