/**
 * Creates an async recursive schema.
 *
 * @param getter The schema getter.
 *
 * @returns An async recursive schema.
 */
export function recursiveAsync(getter) {
    return {
        /**
         * The schema type.
         */
        schema: 'recursive',
        /**
         * The schema getter.
         */
        getter,
        /**
         * Whether it's async.
         */
        async: true,
        /**
         * Parses unknown input based on its schema.
         *
         * @param input The input to be parsed.
         * @param info The parse info.
         *
         * @returns The parsed output.
         */
        async parse(input, info) {
            return getter().parse(input, info);
        },
    };
}
