import { ValiError } from '../../error';
import { executePipeAsync, getErrorAndPipe } from '../../utils';
/**
 * Creates a special schema.
 *
 * @param pipe A validation and transformation pipe.
 *
 * @returns A special schema.
 */
export function specialAsync(check, arg2, arg3) {
    // Get error and pipe argument
    const { error, pipe } = getErrorAndPipe(arg2, arg3);
    // Create and return string schema
    return {
        /**
         * The schema type.
         */
        schema: 'special',
        /**
         * Whether it's async.
         */
        async: true,
        /**
         * Parses unknown input based on its schema.
         *
         * @param input The input to be parsed.
         * @param info The parse info.
         *
         * @returns The parsed output.
         */
        async parse(input, info) {
            // Check type of input
            if (!(await check(input))) {
                throw new ValiError([
                    {
                        reason: 'type',
                        validation: 'special',
                        origin: 'value',
                        message: error || 'Invalid type',
                        input,
                        ...info,
                    },
                ]);
            }
            // Execute pipe and return output
            return executePipeAsync(input, pipe, {
                ...info,
                reason: 'special',
            });
        },
    };
}
