import { ValiError } from '../../error';
import { executePipeAsync, getErrorAndPipe } from '../../utils';
export function stringAsync(arg1, arg2) {
    // Get error and pipe argument
    const { error, pipe } = getErrorAndPipe(arg1, arg2);
    // Create and return async string schema
    return {
        /**
         * The schema type.
         */
        schema: 'string',
        /**
         * Whether it's async.
         */
        async: true,
        /**
         * Parses unknown input based on its schema.
         *
         * @param input The input to be parsed.
         * @param info The parse info.
         *
         * @returns The parsed output.
         */
        parse(input, info) {
            // Check type of input
            if (typeof input !== 'string') {
                throw new ValiError([
                    {
                        reason: 'type',
                        validation: 'string',
                        origin: 'value',
                        message: error || 'Invalid type',
                        input,
                        ...info,
                    },
                ]);
            }
            // Execute pipe and return output
            return executePipeAsync(input, pipe, { ...info, reason: 'string' });
        },
    };
}
