import { ValiError } from '../../error';
/**
 * Creates a custom validation function.
 *
 * @param requirement The validation function.
 * @param error The error message.
 *
 * @returns A validation function.
 */
export function custom(requirement, error) {
    return (input, info) => {
        if (!requirement(input)) {
            throw new ValiError([
                {
                    validation: 'custom',
                    origin: 'value',
                    message: error || 'Invalid input',
                    input,
                    ...info,
                },
            ]);
        }
        return input;
    };
}
