import { ValiError } from '../../error';
/**
 * Creates a async custom validation function.
 *
 * @param requirement The async validation function.
 * @param error The error message.
 *
 * @returns A async validation function.
 */
export function customAsync(requirement, error) {
    return async (input, info) => {
        if (!(await requirement(input))) {
            throw new ValiError([
                {
                    validation: 'custom',
                    origin: 'value',
                    message: error || 'Invalid input',
                    input,
                    ...info,
                },
            ]);
        }
        return input;
    };
}
