import { ValiError } from '../../error';
/**
 * Creates a validation functions that validates the end of a string.
 *
 * @param requirement The end string.
 * @param error The error message.
 *
 * @returns A validation function.
 */
export function endsWith(requirement, error) {
    return (input, info) => {
        if (!input.endsWith(requirement)) {
            throw new ValiError([
                {
                    validation: 'ends_with',
                    origin: 'value',
                    message: error || 'Invalid end',
                    input,
                    ...info,
                },
            ]);
        }
        return input;
    };
}
