import { ValiError } from '../../error';
/**
 * Creates a validation function that checks the value for equality.
 *
 * @param requirement The required value.
 * @param error The error message.
 *
 * @returns A validation function.
 */
export function equal(requirement, error) {
    return (input, info) => {
        if (input !== requirement) {
            throw new ValiError([
                {
                    validation: 'equal',
                    origin: 'value',
                    message: error || 'Invalid input',
                    input,
                    ...info,
                },
            ]);
        }
        return input;
    };
}
