import { ValiError } from '../../error';
/**
 * Creates a validation functions that validates the content of a string or array.
 *
 * @param requirement The content to be included.
 * @param error The error message.
 *
 * @returns A validation function.
 */
export function includes(requirement, error) {
    return (input, info) => {
        if (!input.includes(requirement)) {
            throw new ValiError([
                {
                    validation: 'includes',
                    origin: 'value',
                    message: error || 'Invalid content',
                    input,
                    ...info,
                },
            ]);
        }
        return input;
    };
}
