import { ValiError } from '../../error';
/**
 * Creates a validation functions that validates the range of a string, number or date.
 *
 * @param requirement The maximum range.
 * @param error The error message.
 *
 * @returns A validation function.
 */
export function maxRange(requirement, error) {
    return (input, info) => {
        if (input > requirement) {
            throw new ValiError([
                {
                    validation: 'max_range',
                    origin: 'value',
                    message: error || 'Invalid range',
                    input,
                    ...info,
                },
            ]);
        }
        return input;
    };
}
