import { ValiError } from '../../error';
/**
 * Creates a validation functions that validates the MIME type of a file.
 *
 * @param requirement The MIME types.
 * @param error The error message.
 *
 * @returns A validation function.
 */
export function mimeType(requirement, error) {
    return (input, info) => {
        if (!requirement.includes(input.type)) {
            throw new ValiError([
                {
                    validation: 'mime_type',
                    origin: 'value',
                    message: error || 'Invalid MIME type',
                    input,
                    ...info,
                },
            ]);
        }
        return input;
    };
}
