import { ValiError } from '../../error';
/**
 * Creates a validation functions that validates the size of a map, set or blob.
 *
 * @param requirement The minimum size.
 * @param error The error message.
 *
 * @returns A validation function.
 */
export function minSize(requirement, error) {
    return (input, info) => {
        if (input.size < requirement) {
            throw new ValiError([
                {
                    validation: 'min_size',
                    origin: 'value',
                    message: error || 'Invalid size',
                    input,
                    ...info,
                },
            ]);
        }
        return input;
    };
}
