import { ValiError } from '../../error';
/**
 * Creates a validation functions that validates the start of a string.
 *
 * @param requirement The start string.
 * @param error The error message.
 *
 * @returns A validation function.
 */
export function startsWith(requirement, error) {
    return (input, info) => {
        if (!input.startsWith(requirement)) {
            throw new ValiError([
                {
                    validation: 'starts_with',
                    origin: 'value',
                    message: error || 'Invalid start',
                    input,
                    ...info,
                },
            ]);
        }
        return input;
    };
}
