import { ValiError } from '../../error';
/**
 * Creates a validation functions that validates a UUID.
 *
 * @param error The error message.
 *
 * @returns A validation function.
 */
export function uuid(error) {
    return (input, info) => {
        if (!/^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}$/i.test(input)) {
            throw new ValiError([
                {
                    validation: 'uuid',
                    origin: 'value',
                    message: error || 'Invalid UUID',
                    input,
                    ...info,
                },
            ]);
        }
        return input;
    };
}
