import { type ObjectOutput, type ObjectSchema, type ObjectSchemaAsync, type ObjectShapesAsync, type OptionalSchemaAsync } from '../../schemas';
import type { Pipe } from '../../types';
/**
 * Partial object schema type.
 */
type Partial<TObjectSchema extends ObjectShapesAsync> = {
    [TKey in keyof TObjectSchema]: OptionalSchemaAsync<TObjectSchema[TKey]>;
};
/**
 * Creates an async object schema consisting of all properties of an existing
 * object schema set to optional.
 *
 * @param schema The affected scheme.
 * @param pipe A validation and transformation pipe.
 *
 * @returns An async object schema.
 */
export declare function partialAsync<TObjectSchema extends ObjectSchema<any> | ObjectSchemaAsync<any>>(schema: TObjectSchema, pipe?: Pipe<ObjectOutput<Partial<TObjectSchema['object']>>>): ObjectSchemaAsync<Partial<TObjectSchema['object']>>;
/**
 * Creates an async object schema consisting of all properties of an existing
 * object schema set to optional.
 *
 * @param schema The affected scheme.
 * @param error The error message.
 * @param pipe A validation and transformation pipe.
 *
 * @returns An async object schema.
 */
export declare function partialAsync<TObjectSchema extends ObjectSchema<any> | ObjectSchemaAsync<any>>(schema: TObjectSchema, error?: string, pipe?: Pipe<ObjectOutput<Partial<TObjectSchema['object']>>>): ObjectSchemaAsync<Partial<TObjectSchema['object']>>;
export {};
