import type { BaseSchema } from '../../types';
/**
 * Enum value type.
 */
export type EnumValue = Readonly<[string, ...string[]]>;
/**
 * Enum schema type.
 */
export type EnumSchema<TEnumValue extends EnumValue, TOutput = TEnumValue[number]> = BaseSchema<TEnumValue[number], TOutput> & {
    schema: 'enum';
    enum: TEnumValue;
};
/**
 * Creates a enum schema.
 *
 * @param enum The enum value.
 * @param error The error message.
 *
 * @returns A enum schema.
 */
export declare function enumType<TEnumValue extends EnumValue>(enumValue: TEnumValue, error?: string): EnumSchema<TEnumValue>;
